Module sync

Module sync 

Store-integrated sync: message ingestion and per-folder cursor backfill.

Re-exports

pub use crate::util::datetime_to_ms;
pub use crate::util::ms_to_display;

Functions

backfill
Fetches MAP messages and upserts them into the store using per-folder cursor anchors.
backfill_catch_up
Runs an incremental backfill across all folders using per-folder cursor anchors.